==> recastai-lib-browser-1.0.3.tgz: package/README.md <==
# Recasti.AI - JavaScript Library
[logo]: https://github.com/RecastAI/SDK-NodeJs/blob/master/misc/logo-inline.png "Recast.AI"

![alt text][logo]


## Synospis

This module is a JS Client interface to the [Recast.AI](https://recast.ai) API. It allows you to make request to your bots, by voices or by text.

## Installation

### npm

```bash
npm install --save recastai-lib-browser
```
```javascript
import Recast from 'recastai-lib-browser'
```

### bower

```bash
bower install recastai-lib-browser
```
```html
<script src="bower_components/recastai-lib-browser/recastai-lib-browser.js"></script>
```

### CDN

```html
<script src="https://cdn.recast.ai/scripts/recastai-lib-browser.js"></script>
```

## Usage

```javascript
/*
* the object option, in a an option and is not required to work.
* if you don't specify any language, english will be set as default
*/
var option = {
  language: 'en',/* 'en' or 'fr' */
  deBug: true, /*will add console log at the end of some function */
}
var recast = new Recast('YOUR_TOKEN',option)
```

## Specs
This module contains 1 classes, with 4 methodes :
* Start recording,: Will allow you to record your voices and will return the response of Recast.AI.
* Stop recording: Will stop the recording, and tell Recast.AI to processe the vocal message send by startRecording().
* Text request: Will allow you to send a textRequest, it will return you the response of Recast.AI.
* You can use all the metode of the [Recast.AI - SDK Node.js](https://github.com/RecastAI/SDK-NodeJS).

## Start recording
* startRecording(), will ask the permission to use your microphone, will open a webSocket and recorde your voice for 10 sec max.
* this function return a promise.
```javascript
recast.startRecording().then(function(res){
  console.log(res)
    /*your code */
}).catch(function(e){
  console.log(e)
})
```

## Stop recording
* Stop recording, will send to Recast.AI a formated message to tell the recoding is finish.
```javascript
recast.stopRecording()
```

## Text request
* textRecast(), will send your text to Recast.AI and will return you a promise whith the response of Recast.AI.
```javascript
recast.textRequest('YOUR_TEXT').then(function(res){
  console.log(res)
    /*your code */
}).catch(function(e){
  console.log(e)
})
```

## Example with a SDK NodeJS methode
* You can find more example here: [README](https://github.com/RecastAI/SDK-NodeJS).
```javascript
var text = 'Hello'

recast.textRequest(text).then(function(res){

  var intent = res.intent()

  if (intent === 'greetings') {
    console.log(res)
    /*your code */
  }
}).catch(function(e){
  console.log(e)
})
```
* you can find all the code on this part of the [REPO](https://github.com/RecastAI/Library-JavaScript/tree/master/example/NPM-example) with a typical html file and a webpack config to get started.

## More

You can view the whole API reference at [man.recast.ai](https://man.recast.ai).

## Author

Henri Floren, henri.floren@recast.ai

You can follow us on Twitter at [@recastai](https://twitter.com/recastai) for updates and releases.

## License

Copyright (c) [2016] [Recast.AI](https://recast.ai)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> recastai-lib-browser-1.1.1.tgz: package/README.md <==
# Recast.ai - JavaScript Library
[logo]: https://github.com/RecastAI/SDK-NodeJs/blob/master/misc/logo-inline.png "Recast.AI"

![alt text][logo]


## Synospis

This module is a JS Client interface to the [Recast.AI](https://recast.ai) API. It allows you to make requests to your bots, by speech or by text.

## Installation

### npm

```bash
npm install --save recastai-lib-browser
```
```javascript
import Recast from 'recastai-lib-browser'
```

### bower

```bash
bower install recastai-lib-browser
```
```html
<script src="bower_components/recastai-lib-browser/recastai-lib-browser.js"></script>
```

### CDN

```html
<script src="https://cdn.recast.ai/scripts/recastai-lib-browser.js"></script>
```

## Usage

```javascript
/*
* the option parameter is optional.
* if you don't specify any language, english will be set as default
*/
var option = {
  language: 'en',/* 'en' or 'fr' */
  debug: true, /*will add console log at the end of some function */
}
var recast = new Recast('YOUR_TOKEN',option)
```

## Specs
This module contains 1 classes, with 4 methods :
* Start recording: allows you to record your voice and will return the response of Recast.AI.
* Stop recording: stop the recording, and tells Recast.AI to process the vocal message send by startRecording().
* Text request: allows you to send a textRequest, it will return the response of Recast.AI.
* You can use all the method of the [Recast.AI - SDK Node.js](https://github.com/RecastAI/SDK-NodeJS).

## Start recording
* startRecording() will ask the permission to use your microphone, will open a webSocket and record your voice for 10 sec max.
* this function return a promise.
```javascript
recast.startRecording().then(function(res){
  console.log(res)
    /*your code */
}).catch(function(e){
  console.log(e)
})
```

## Stop recording
* Stop recording will send to Recast.AI a formated message to tell the recoding is done.
```javascript
recast.stopRecording()
```

## Text request
* textRecast() will send your text to Recast.AI and will return a promise with the response of Recast.AI.
```javascript
recast.textRequest('YOUR_TEXT').then(function(res){
  console.log(res)
    /*your code */
}).catch(function(e){
  console.log(e)
})
```

## Example with a SDK NodeJS method
* You can find more examples here: [README](https://github.com/RecastAI/SDK-NodeJS).
```javascript
var text = 'Hello'

recast.textRequest(text).then(function(res){

  var intent = res.intent()

  if (intent === 'greetings') {
    console.log(res)
    /*your code */
  }
}).catch(function(e){
  console.log(e)
})
```
* you can find all the code on this part of the [REPO](https://github.com/RecastAI/Library-JavaScript/tree/master/example/NPM-example) with a typical html file and a webpack config to get started.

## More

You can view the whole API reference at [man.recast.ai](https://man.recast.ai).

## Author

Henri Floren, henri.floren@recast.ai

You can follow us on Twitter at [@recastai](https://twitter.com/recastai) for updates and releases.

## License

Copyright (c) [2016] [Recast.AI](https://recast.ai)

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
